==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/WSCRpulldownMenu.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCRPULLDOWNMENU_H
#define WSCRPULLDOWNMENU_H

#include <WScom.h>
#include <WSCRvlabel.h>
#include <WSCstring.h>
#include <WSDserialize.h>
#include <WSCconductor.h>

class WSCRpulldownMenu :public WSCRvlabel{

 protected:
 public:
  WSCRpulldownMenu();
  virtual ~WSCRpulldownMenu();

  void onActivate();
  long getValue();
  long getItems();

  long setItemSensitive(short no,WSCbool flag);
  long setValueSensitive(short id,WSCbool flag);

  WSMFclassDef(WSCRpulldownMenu,WSCRvlabel);
};
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSCRpulldownMenu.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCRPULLDOWNMENU_H
#define WSCRPULLDOWNMENU_H

#include <WScom.h>
#include <WSCRvlabel.h>
#include <WSCstring.h>
#include <WSDserialize.h>
#include <WSCconductor.h>

class WSCRpulldownMenu :public WSCRvlabel{

 protected:
 public:
  WSDLEX32 WSCRpulldownMenu();
  WSDLEX32 virtual ~WSCRpulldownMenu();

  WSDLEX32 void onActivate();
  WSDLEX32 long getValue();
  WSDLEX32 long getItems();

  WSDLEX32 long setItemSensitive(short no,WSCbool flag);
  WSDLEX32 long setValueSensitive(short id,WSCbool flag);

  WSMFclassDef(WSCRpulldownMenu,WSCRvlabel);
};
#endif
